#!/bin/bash
#-------------------------------------------------------------------------
#
#          DELL COMPUTER CORPORATION PROPRIETARY INFORMATION
#
#  This software is supplied under the terms of a license agreement or
#  nondisclosure agreement with Dell Computer Corporation and may not
#  be copied or disclosed except in accordance with the terms of that
#  agreement.
#
#  Copyright (c) 2015 Dell Computer Corp. All Rights Reserved.
#
#  Abstract/Purpose:
#  Enable/Disable Host SNMP Trap feature of iDRAC Service Moudle.
#  Follow the EnableiDRACSNMPTrapusage() function for the usage guide.
#------------------------------------------------------------------------

EnableiDRACSNMPTrapusage()
{
	echo "Usage: Ensure Net-SNMP package is installed with SMUX protocol enabled. the command usage is as follows -"
	echo "       Enable-iDRACSNMPTrap.sh 1/enable          => Enable SNMP trap feature in iDRAC Service Module; Net-SNMP trap configuration should be done by Server Administrator."
	echo "       Enable-iDRACSNMPTrap.sh 1/enable --force  => Enable SNMP trap feature in iDRAC Service Module; Net-SNMP re-configuration is attempted; Trap Destinations need to be configured by Server Administrator."
	echo "       Enable-iDRACSNMPTrap.sh 0/disable         => Disable SNMP trap feature in iDRAC Service Module; Net-SNMP configuration should be done by Server Administrator."
	echo "       Enable-iDRACSNMPTrap.sh 0/disable --force => Disable SNMP trap feature in iDRAC Service Module; Net-SNMP re-configuration is attempted."
} 

ServiceModuleTrapEnable()
{
	if [ "$1" == "1" ]
	then 
		#Enable Trap
		touch /opt/dell/srvadmin/iSM/etc/enable_trap
		echo "SNMP Trap feature is enabled in iDRAC Service Module."
	else
		#Disable Trap
		rm -f /opt/dell/srvadmin/iSM/etc/enable_trap
		echo "SNMP Trap feature is disabled in iDRAC Service Module."
	fi 
}

SMUXNotificationMsg()
{
	echo "iDRAC Service Module smux peer is configured, please ensure smux is enabled for master snmp agent." 
}

EnableiDRACSNMPConfigureNetSNMP()
{
	if [ "$1" == "1" ]
	then  
		if [ -e /etc/snmp/snmpd.conf ] 
		then
			cat /opt/dell/srvadmin/iSM/etc/ism_snmpd.conf >> /etc/snmp/snmpd.conf
		else
			echo "Please install net-snmp to enable this feature!"
			exit 1
		fi
	else
		#restore
		cat /etc/snmp/snmpd.conf | grep -v "`cat /opt/dell/srvadmin/iSM/etc/ism_snmpd.conf`" > /opt/dell/srvadmin/iSM/etc/snmpd_backup.conf
        	mv /opt/dell/srvadmin/iSM/etc/snmpd_backup.conf /etc/snmp/snmpd.conf
	fi

	if [ -e /etc/init.d/snmpd ]
	then
		/etc/init.d/snmpd restart
		if [ $? -ne 0 ]
		then
			echo "snmpd could not be started, please contact administrator to install and run net-snmp!!"
			exit 1
		fi
	else
		if [ -e /usr/bin/systemctl ] && [ -e /usr/lib/systemd/system/snmpd.service ]
		then
			systemctl enable snmpd.service
			systemctl restart snmpd.service
			if [ $? -ne 0 ]
			then
				echo "snmpd could not be started, please contact administrator to install and run net-snmp!!!!"
				exit 1
			fi
		else
			echo "Please install net-snmp to enable this feature!"
			exit 1
		fi
	fi
}

if [ $# -eq 0 ] || [ $# -gt 2 ]
then
	EnableiDRACSNMPTrapusage
	exit 1
fi
command="$1"
if [ "$command" == "1" ] || [ "$command" == "enable" ]
then

	if [ $# -eq 2 ]
	then
		if [ "$2" == "--force" ]
		then
			EnableiDRACSNMPConfigureNetSNMP "0"
			EnableiDRACSNMPConfigureNetSNMP "1"
			SMUXNotificationMsg
			ServiceModuleTrapEnable "1"
			exit 0
		else
			EnableiDRACSNMPTrapusage
			exit 1
		fi
	else
		ServiceModuleTrapEnable "1"
		echo "Please configure the Net-SNMP master agent to send traps; ensure smux is enabled; for iDRAC Service Module smux peer configuration please consult /opt/dell/srvadmin/iSM/etc/ism_snmpd.conf and then restart the snmpd service."
		exit 0
	fi


elif [ "$command" == "0" ] || [ "$command" == "disable" ]
then
	# restore snmpd.conf
	if [ $# -eq 2 ]
	then
                if [ "$2" == "--force" ]
                then
			ServiceModuleTrapEnable "0"
                        EnableiDRACSNMPConfigureNetSNMP "0"
                        exit 0
                else
                        EnableiDRACSNMPTrapusage
                        exit 1
                fi
        else
		ServiceModuleTrapEnable "0"
                echo "Please re-configure the Net-SNMP master agent by removing the smux peer entries for iDRAC Service Module. please consult /opt/dell/srvadmin/iSM/etc/ism_snmpd.conf for smux peer configuration of iDRAC Service Module."
                exit 0
        fi

else
	EnableiDRACSNMPTrapusage
	exit 1
fi

exit 0



